==> jc-1.4.0.tar.gz: java/lang/VirtualMachineError.h <==
// public abstract class java.lang.VirtualMachineError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c7632ae877826bc6 java_lang_VirtualMachineError

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_java_lang_VirtualMachineError_H_
#define _JC_java_lang_VirtualMachineError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_VirtualMachineError$sub_refs	_jc_java_lang_VirtualMachineError$sub_refs;
typedef struct _jc_java_lang_VirtualMachineError$sub_nonrefs	_jc_java_lang_VirtualMachineError$sub_nonrefs;
typedef struct _jc_java_lang_VirtualMachineError$refs	_jc_java_lang_VirtualMachineError$refs;
typedef struct _jc_java_lang_VirtualMachineError$nonrefs	_jc_java_lang_VirtualMachineError$nonrefs;
typedef struct _jc_java_lang_VirtualMachineError$object	_jc_java_lang_VirtualMachineError$object;

typedef struct _jc_java_lang_VirtualMachineError$fields_struct	_jc_java_lang_VirtualMachineError$fields_struct;
typedef const struct _jc_java_lang_VirtualMachineError$vmethods	_jc_java_lang_VirtualMachineError$vmethods;
typedef const struct _jc_java_lang_VirtualMachineError$vtable	_jc_java_lang_VirtualMachineError$vtable;
typedef const struct _jc_java_lang_VirtualMachineError$vtype	_jc_java_lang_VirtualMachineError$vtype;

// Class fields structure
struct _jc_java_lang_VirtualMachineError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_VirtualMachineError$fields_struct _jc_java_lang_VirtualMachineError$class_fields;

// Constructors
extern void _jc_java_lang_VirtualMachineError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VirtualMachineError$object *);
extern void _jc_java_lang_VirtualMachineError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_VirtualMachineError$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_VirtualMachineError$vmethods {
};

// Vtable
struct _jc_java_lang_VirtualMachineError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_VirtualMachineError$vmethods	java_lang_VirtualMachineError;
};

// Vtype
struct _jc_java_lang_VirtualMachineError$vtype {
	_jc_type			type;
	_jc_java_lang_VirtualMachineError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VirtualMachineError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VirtualMachineError$refs {
    _jc_java_lang_VirtualMachineError$sub_refs	java_lang_VirtualMachineError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VirtualMachineError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VirtualMachineError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_VirtualMachineError$sub_nonrefs	java_lang_VirtualMachineError;
};

// Object instance structure
struct _jc_java_lang_VirtualMachineError$object {
	_jc_java_lang_VirtualMachineError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VirtualMachineError$vtype	*vtype;
	_jc_java_lang_VirtualMachineError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VirtualMachineError$vtype _jc_java_lang_VirtualMachineError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VirtualMachineError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VirtualMachineError$class_object;

#endif	/* _JC_java_lang_VirtualMachineError_H_ */

==> jc-1.4.6.tar.gz: java/lang/VirtualMachineError.h <==
// public abstract class java.lang.VirtualMachineError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c7632ae877826bc6 java_lang_VirtualMachineError

// header file dependencies
// @dep_header java_lang_Error

#include "java/lang/Error.h"

#ifndef _JC_java_lang_VirtualMachineError_H_
#define _JC_java_lang_VirtualMachineError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_VirtualMachineError$sub_refs	_jc_java_lang_VirtualMachineError$sub_refs;
typedef struct _jc_java_lang_VirtualMachineError$sub_nonrefs	_jc_java_lang_VirtualMachineError$sub_nonrefs;
typedef struct _jc_java_lang_VirtualMachineError$refs	_jc_java_lang_VirtualMachineError$refs;
typedef struct _jc_java_lang_VirtualMachineError$nonrefs	_jc_java_lang_VirtualMachineError$nonrefs;
typedef struct _jc_java_lang_VirtualMachineError$object	_jc_java_lang_VirtualMachineError$object;

typedef struct _jc_java_lang_VirtualMachineError$fields_struct	_jc_java_lang_VirtualMachineError$fields_struct;
typedef const struct _jc_java_lang_VirtualMachineError$vmethods	_jc_java_lang_VirtualMachineError$vmethods;
typedef const struct _jc_java_lang_VirtualMachineError$vtable	_jc_java_lang_VirtualMachineError$vtable;
typedef const struct _jc_java_lang_VirtualMachineError$vtype	_jc_java_lang_VirtualMachineError$vtype;

// Class fields structure
struct _jc_java_lang_VirtualMachineError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_VirtualMachineError$fields_struct _jc_java_lang_VirtualMachineError$class_fields;

// Constructors
extern void _jc_java_lang_VirtualMachineError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VirtualMachineError$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_VirtualMachineError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_VirtualMachineError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_VirtualMachineError$vmethods {
};

// Vtable
struct _jc_java_lang_VirtualMachineError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_VirtualMachineError$vmethods	java_lang_VirtualMachineError;
};

// Vtype
struct _jc_java_lang_VirtualMachineError$vtype {
	_jc_type			type;
	_jc_java_lang_VirtualMachineError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VirtualMachineError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VirtualMachineError$refs {
    _jc_java_lang_VirtualMachineError$sub_refs	java_lang_VirtualMachineError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VirtualMachineError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VirtualMachineError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_VirtualMachineError$sub_nonrefs	java_lang_VirtualMachineError;
};

// Object instance structure
struct _jc_java_lang_VirtualMachineError$object {
	_jc_java_lang_VirtualMachineError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VirtualMachineError$vtype	*vtype;
	_jc_java_lang_VirtualMachineError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VirtualMachineError$vtype _jc_java_lang_VirtualMachineError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VirtualMachineError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VirtualMachineError$class_object;

#endif	/* _JC_java_lang_VirtualMachineError_H_ */
